/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model;

import java.util.*;

/**
 * Programmatic implementation of the constraint expressed by a specific facet.  For example, an implementation of 
 * this interface would know about what it means to have "maximum cardinality" and would be able to check to see if
 * a particular value was consistent with this constraint.  The Facet itself is really just a placeholder and has no 
 * knowledge of the actual constraint that it represents.  The logic is all in the implementations of this interface.
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public interface FacetConstraint {

    boolean areValidValues(Frame frame, Slot slot, Collection slotValues, Collection facetValues);

    String getInvalidValuesText(Frame frame, Slot slot, Collection slotValues, Collection facetValues);

    String getInvalidValueText(Frame frame, Slot slot, Object value, Collection facetValues);

    boolean isValidValue(Frame frame, Slot slot, Object item, Collection facetValues);

    Collection resolve(Collection existingValues, Collection newValues);
}
