/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore.undo;

import java.util.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.*;

class SetDirectTemplateFacetValuesCommand extends AbstractCommand {
    private Slot slot;
    private Cls cls;
    private Facet facet;
    private Collection values;
    private List _oldValues;

    SetDirectTemplateFacetValuesCommand(FrameStore delegate, Slot slot, Cls cls, Facet facet, Collection values) {
        super(delegate);
        this.slot = slot;
        this.cls = cls;
        this.facet = facet;
        this.values = new ArrayList(values);
        String description = "Set template facet " + getText(facet) + " at class " + getText(cls) + " and slot "
                + getText(slot) + " to values " + getText(values);
        setDescription(description);
    }

    public Object doIt() {
        _oldValues = getDelegate().getDirectTemplateFacetValues(cls, slot, facet);
        getDelegate().setDirectTemplateFacetValues(cls, slot, facet, values);
        return null;
    }

    public void undoIt() {
        getDelegate().setDirectTemplateFacetValues(cls, slot, facet, _oldValues);
    }

    public void redoIt() {
        getDelegate().setDirectTemplateFacetValues(cls, slot, facet, values);
    }
}