/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.socket;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.Socket;
import java.util.logging.Logger;

import edu.stanford.smi.protege.util.Log;


public class SocketWithAspects extends Socket {
    static Logger log = Log.getLogger(SocketWithAspects.class);
    
    private SocketAspect myAspects;

    public SocketWithAspects(boolean useCompression) {
        myAspects = new SocketAspect() {

            public SocketAspect getDelegate() {
                return null;
            }

            public InputStream getInputStream() throws IOException {
                return defaultGetInputStream();
            }

            public OutputStream getOutputStream()  throws IOException {
                return defaultGetOutputStream();
            }
            
            public void close() throws IOException {
                defaultClose();
            }
            
        };
        if (SimulateDelayAspect.useSimulatedDelay()) {
            myAspects = new SimulateDelayAspect(myAspects);
        }
        if (useCompression) {
            myAspects = new CompressionAspect(myAspects);
        }
        if (MonitoringAspect.useMonitoring()) {
            myAspects = new MonitoringAspect(myAspects);
        }
        if (TeeAspect.doTeeOuput()) {
            myAspects = new TeeAspect(myAspects);
        }
    }
    
    public InputStream getInputStream() throws IOException {
        return myAspects.getInputStream();
    }
    
    private InputStream defaultGetInputStream() throws IOException {
        return super.getInputStream();
    }
    
    public OutputStream getOutputStream() throws IOException {
        return myAspects.getOutputStream();
    }
    
    private OutputStream defaultGetOutputStream() throws IOException {
        return super.getOutputStream();
    }
    
    public void close() throws IOException {
        myAspects.close();
    }
    
    private void defaultClose() throws IOException {
        super.close();
    }
}
