/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.storage.database;

import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import edu.stanford.smi.protege.model.Facet;
import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.FrameFactory;
import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.Slot;
import edu.stanford.smi.protege.model.framestore.NarrowFrameStore;
import edu.stanford.smi.protege.model.framestore.Sft;
import edu.stanford.smi.protege.util.transaction.TransactionMonitor;

public interface DatabaseFrameDb extends NarrowFrameStore {

    void initialize(FrameFactory factory,
                           String driver,
                           String url, String user, String pass, String table,
                           boolean isInclude);
    
    void close();
    
    String getTableName();

    void removeValue(Frame frame, Slot slot, Facet facet, boolean isTemplate, Object value);

    Map<Sft,List> getFrameValues(Frame frame);

    void overwriteKB(KnowledgeBase kb,
                                boolean saveFrames) throws SQLException;

    TransactionMonitor getTransactionStatusMonitor();
}